OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "Adres bilinmiyor",
    "No result." : "Sonuç yok.",
    "Malformed JSON data." : "JSON verileri bozuk.",
    "Error" : "Hata",
    "Weather status" : "Hava durumu",
    "Weather status in your dashboard" : "Panonuz için hava durumu",
    "Weather status integrated in the Dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Pano uygulaması ile bütünleşik hava durumu.\n    Kullanıcının konumu el ile de ayarlanabileceği gibi otomatik olarak da algılanabilir. 6 saatlik tahmin görüntülenir.\n    Hava durumu Takvim gibi diğer uygulamalarla da kullanılabilir.",
    "Detect location" : "Konum algılansın",
    "Set custom address" : "Özel adres belirtin",
    "Favorites" : "Sık kullanılanlar",
    "{temperature} {unit} clear sky later today" : "{temperature} {unit} bugün açık",
    "{temperature} {unit} clear sky" : "{temperature} {unit} açık",
    "{temperature} {unit} cloudy later today" : "{temperature} {unit} bugün bulutlu",
    "{temperature} {unit} cloudy" : "{temperature} {unit} bulutlu",
    "{temperature} {unit} fair weather later today" : "{temperature} {unit} bugün güzel",
    "{temperature} {unit} fair weather" : "{temperature} {unit} güzel",
    "{temperature} {unit} partly cloudy later today" : "{temperature} {unit} bugün parçalı bulutlu",
    "{temperature} {unit} partly cloudy" : "{temperature} {unit} parçalı bulutlu",
    "{temperature} {unit} foggy later today" : "{temperature} {unit} bugün sisli",
    "{temperature} {unit} foggy" : "{temperature} {unit} sisli",
    "{temperature} {unit} light rainfall later today" : "{temperature} {unit} bugün hafif yağmurlu",
    "{temperature} {unit} light rainfall" : "{temperature} {unit} hafif yağmurlu",
    "{temperature} {unit} rainfall later today" : "{temperature} {unit} bugün hafif yağmurlu",
    "{temperature} {unit} rainfall" : "{temperature} {unit} yağmurlu",
    "{temperature} {unit} heavy rainfall later today" : "{temperature} {unit} bugün şiddetli yağmurlu",
    "{temperature} {unit} heavy rainfall" : "{temperature} {unit} şiddetli yağmurlu",
    "{temperature} {unit} rainfall showers later today" : "{temperature} {unit} bugün sağanak yağışlı",
    "{temperature} {unit} rainfall showers" : "{temperature} {unit} sağanak yağışlı",
    "{temperature} {unit} light rainfall showers later today" : "{temperature} {unit} bugün hafif sağanak yağışlı",
    "{temperature} {unit} light rainfall showers" : "{temperature} {unit} hafif sağanak yağışlı",
    "{temperature} {unit} heavy rainfall showers later today" : "{temperature} {unit} bugün şiddetli sağanak yağışlı",
    "{temperature} {unit} heavy rainfall showers" : "{temperature} {unit} şiddetli sağanak yağışlı",
    "More weather for {adr}" : "{adr} için geniş hava durumu",
    "Loading weather" : "Hava durumu yükleniyor",
    "Remove from favorites" : "Sık kullanılanlardan kaldır",
    "Add as favorite" : "Sık kullanılanlara ekle",
    "You are not logged in." : "Oturum açmamışsınız.",
    "There was an error getting the weather status information." : "Hava durumu bilgileri alınırken bir sorun çıktı.",
    "No weather information found" : "Hava durumu bilgileri bulunamadı.",
    "Location not found" : "Konum bulunamadı",
    "There was an error setting the location address." : "Konum adresi ayarlanırken bir sorun çıktı.",
    "There was an error setting the location." : "Konum ayarlanırken bir sorun çıktı.",
    "There was an error saving the mode." : "Kip kaydedilirken bir sorun çıktı.",
    "There was an error using personal address." : "Kişisel adres kullanılırken bir sorun çıktı.",
    "Set location for weather" : "Hava durumu için konumu ayarlayın",
    "{temperature} {unit} Clear sky at {time}" : "{temperature} {unit} Açık {time}",
    "{temperature} {unit} Cloudy at {time}" : "{temperature} {unit} Bulutlu {time}",
    "{temperature} {unit} Fair day at {time}" : "{temperature} {unit} Gündüz {time}",
    "{temperature} {unit} Fair night at {time}" : "{temperature} {unit} Gece {time}",
    "{temperature} {unit} Partly cloudy at {time}" : "{temperature} {unit} Parçalı bulutlu {time}",
    "{temperature} {unit} Foggy at {time}" : "{temperature} {unit} Sisli {time}",
    "{temperature} {unit} Light rain at {time}" : "{temperature} {unit} Hafif yağışlı {time}",
    "{temperature} {unit} Rain at {time}" : "{temperature} {unit} Yağışlı {time}",
    "{temperature} {unit} Heavy rain at {time}" : "{temperature} {unit} şiddetli yağmur {time}",
    "{temperature} {unit} Rain showers at {time}" : "{temperature} {unit} Sağanak yağış {time}",
    "{temperature} {unit} Light rain showers at {time}" : "{temperature} {unit} Hafif sağnak {time}",
    "{temperature} {unit} Heavy rain showers at {time}" : "{temperature} {unit} şiddetli sağanak yağış {time}"
},
"nplurals=2; plural=(n > 1);");
